@@ -23,9 +23,9 @@
 #include <QString>
 #include "qmmp_export.h"
 
-#define QMMP_VERSION_MAJOR 1
-#define QMMP_VERSION_MINOR 5
-#define QMMP_VERSION_PATCH 0
+#define QMMP_VERSION_MAJOR 2
+#define QMMP_VERSION_MINOR 0
+#define QMMP_VERSION_PATCH 2
 #define QMMP_VERSION_STABLE 1
 
 #define QMMP_VERSION_INT (QMMP_VERSION_MAJOR<<16 | QMMP_VERSION_MINOR<<8 | QMMP_VERSION_PATCH)
@@ -39,15 +39,6 @@
 #define QStringToFileName(s) s.toLocal8Bit().constData()
 #endif
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 7, 0))
-// this adds const to non-const objects (like std::as_const)
-template <typename T>
-Q_DECL_CONSTEXPR typename std::add_const<T>::type &qAsConst(T &t) noexcept { return t; }
-// prevent rvalue arguments:
-template <typename T>
-void qAsConst(const T &&) = delete;
-#endif
-
 
 /*! @brief The Qmmp class stores global settings and enums.
  * @author Ilya Kotov <forkotov02@ya.ru>
@@ -197,11 +188,6 @@ public:
     static bool isPortable();
 #endif
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
-    static QString wildcardToRegularExpression(const QString &pattern);
-    static QString anchoredPattern(const QString &expression);
-#endif
-
 private:
     static QString m_configDir;
     static QString m_langID;
